@@ -3,4 +3,4 @@ JS_DEFAULT_DATE_FORMAT = "dd/MM/yyyy"
 
 # CDN FOR STATICS
 DJANGO_BOOSTRAP_ITALIA_USE_CDN = False
-DJANGO_BOOSTRAP_ITALIA_CDN = 'https://cdn.jsdelivr.net/npm/bootstrap-italia@1.6.2/dist'
+DJANGO_BOOSTRAP_ITALIA_CDN = 'https://cdn.jsdelivr.net/npm/bootstrap-italia@1.6.4-1/dist'
